"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = "abst"
__description__ = (
    "CLI Command making OCI Bastion simple and fast"
)

__version__ = "1.2.1"
__author__ = "Jiri Otoupal"
__author_email__ = "jiri-otoupal@ips-database.eu"
__license__ = "Apache 2.0"
__url__ = "https://github.com/jiri-otoupal/abst"
